OH_ArkUI_SurfaceCallback_SetSurfaceCreatedEvent

Function OH_ArkUI_SurfaceCallback_SetSurfaceCreatedEvent 

pub unsafe extern "C" fn OH_ArkUI_SurfaceCallback_SetSurfaceCreatedEvent(
    callback: *mut OH_ArkUI_SurfaceCallback,
    onSurfaceCreated: Option<unsafe extern "C" fn(surfaceHolder: *mut OH_ArkUI_SurfaceHolder)>,
)
Available on crate feature api-19 only.
Set the surface created event of the surface callback.

Arguments

  • callback - Indicated the pointer to the surface callback.

  • onSurfaceCreated - Indicates the surface created callback event which will called when the surface is created.

Available since API-level: 19