OH_ArkUI_SurfaceCallback_SetSurfaceDestroyedEvent

Function OH_ArkUI_SurfaceCallback_SetSurfaceDestroyedEvent 

pub unsafe extern "C" fn OH_ArkUI_SurfaceCallback_SetSurfaceDestroyedEvent(
    callback: *mut OH_ArkUI_SurfaceCallback,
    onSurfaceDestroyed: Option<unsafe extern "C" fn(surfaceHolder: *mut OH_ArkUI_SurfaceHolder)>,
)
Available on crate feature api-19 only.
Set the surface destroyed event of the surface callback.

Arguments

  • callback - Indicated the pointer to the surface callback.

  • onSurfaceDestroyed - Indicates the surface destroyed callback event which will called when the surface is destroyed.

Available since API-level: 19