#[repr(C)]pub struct OH_NativeXComponent_HistoricalPoint {
pub id: i32,
pub screenX: f32,
pub screenY: f32,
pub x: f32,
pub y: f32,
pub type_: OH_NativeXComponent_TouchEventType,
pub size: f64,
pub force: f32,
pub timeStamp: i64,
pub titlX: f32,
pub titlY: f32,
pub sourceTool: OH_NativeXComponent_TouchEvent_SourceTool,
}Expand description
Represents the historical point.
Available since API-level: 10
Version: 1.0
Fields
id: i32Unique identifier of a finger.
screenX: f32X coordinate of the touch point relative to the left edge of the screen.
screenY: f32Y coordinate of the touch point relative to the upper edge of the screen.
x: f32X coordinate of the touch point relative to the left edge of the element to touch.
y: f32Y coordinate of the touch point relative to the upper edge of the element to touch.
type_: OH_NativeXComponent_TouchEventTypeTouch type of the touch event.
size: f64Contact area between the finger pad and the screen.
force: f32Pressure of the current touch event.
timeStamp: i64Timestamp of the current touch event.
titlX: f32The angle betweenprojection on plane-X-Y and axis-Z of the current touch event.
titlY: f32The angle betweenprojection on plane-Y-Z and axis-Z of the current touch event.
sourceTool: OH_NativeXComponent_TouchEvent_SourceToolThe sourceTool of the current touch event.