#[repr(transparent)]pub struct OH_NativeXComponent_TouchEventType(pub c_uint);Expand description
Represents the type of touch event.
Available since API-level: 8
Version: 1.0
Tuple Fields
0: c_uintImplementations
Sourceimpl OH_NativeXComponent_TouchEventType
impl OH_NativeXComponent_TouchEventType
Sourcepub const OH_NATIVEXCOMPONENT_DOWN: OH_NativeXComponent_TouchEventType
pub const OH_NATIVEXCOMPONENT_DOWN: OH_NativeXComponent_TouchEventType
Trigger a touch event when a finger is pressed.
Sourcepub const OH_NATIVEXCOMPONENT_UP: OH_NativeXComponent_TouchEventType
pub const OH_NATIVEXCOMPONENT_UP: OH_NativeXComponent_TouchEventType
Trigger a touch event when a finger is lifted.
Sourcepub const OH_NATIVEXCOMPONENT_MOVE: OH_NativeXComponent_TouchEventType
pub const OH_NATIVEXCOMPONENT_MOVE: OH_NativeXComponent_TouchEventType
Trigger a touch event when a finger moves on the screen in pressed state.
Sourcepub const OH_NATIVEXCOMPONENT_CANCEL: OH_NativeXComponent_TouchEventType
pub const OH_NATIVEXCOMPONENT_CANCEL: OH_NativeXComponent_TouchEventType
Trigger an event when a touch event is canceled.
Sourcepub const OH_NATIVEXCOMPONENT_UNKNOWN: OH_NativeXComponent_TouchEventType
pub const OH_NATIVEXCOMPONENT_UNKNOWN: OH_NativeXComponent_TouchEventType
Invalid touch type.