pub unsafe extern "C" fn OH_ArkUI_XComponentSurfaceConfig_SetIsOpaque(
config: *mut ArkUI_XComponentSurfaceConfig,
isOpaque: bool,
)Available on crate feature
api-22 only.Expand description
Set whether the surface held by XComponent needs to be considered opaque, even if the surface has translucent pixel.
Arguments
-
config- A pointer to the object of the XComponent’s surface config. -
isOpaque- Indicates whether the surface held by XComponent needs to be considered opaque, True means needing to be considered opaque, false otherwise.
Available since API-level: 22